# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKIOMetaPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkMetaImageIOPython
else:
    import _itkMetaImageIOPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.ITKIOImageBaseBasePython

def itkMetaImageIO_New():
    return itkMetaImageIO.New()

class itkMetaImageIO(itk.ITKIOImageBaseBasePython.itkImageIOBase):
    r"""Proxy of C++ itkMetaImageIO class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMetaImageIO_Pointer"""
        return _itkMetaImageIOPython.itkMetaImageIO___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMetaImageIO_Pointer"""
        return _itkMetaImageIOPython.itkMetaImageIO_Clone(self)

    def GetMetaImagePointer(self):
        r"""GetMetaImagePointer(self) -> MetaImage *"""
        return _itkMetaImageIOPython.itkMetaImageIO_GetMetaImagePointer(self)

    def SetDataFileName(self, filename):
        r"""
        SetDataFileName(self, filename)

        Parameters
        ----------
        filename: char const *

        """
        return _itkMetaImageIOPython.itkMetaImageIO_SetDataFileName(self, filename)

    def SetDoublePrecision(self, precision):
        r"""
        SetDoublePrecision(self, precision)

        Parameters
        ----------
        precision: unsigned int

        """
        return _itkMetaImageIOPython.itkMetaImageIO_SetDoublePrecision(self, precision)

    def SetSubSamplingFactor(self, _arg):
        r"""
        SetSubSamplingFactor(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkMetaImageIOPython.itkMetaImageIO_SetSubSamplingFactor(self, _arg)

    def GetSubSamplingFactor(self):
        r"""GetSubSamplingFactor(self) -> unsigned int"""
        return _itkMetaImageIOPython.itkMetaImageIO_GetSubSamplingFactor(self)

    @staticmethod
    def SetDefaultDoublePrecision(precision):
        r"""
        SetDefaultDoublePrecision(precision)

        Parameters
        ----------
        precision: unsigned int

        """
        return _itkMetaImageIOPython.itkMetaImageIO_SetDefaultDoublePrecision(precision)

    @staticmethod
    def GetDefaultDoublePrecision():
        r"""GetDefaultDoublePrecision() -> unsigned int"""
        return _itkMetaImageIOPython.itkMetaImageIO_GetDefaultDoublePrecision()
    __swig_destroy__ = _itkMetaImageIOPython.delete_itkMetaImageIO

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMetaImageIO

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMetaImageIOPython.itkMetaImageIO_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMetaImageIO

        Create a new object of the class itkMetaImageIO and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMetaImageIO.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMetaImageIO.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMetaImageIO.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMetaImageIO in _itkMetaImageIOPython:
_itkMetaImageIOPython.itkMetaImageIO_swigregister(itkMetaImageIO)

def itkMetaImageIOFactory_New():
    return itkMetaImageIOFactory.New()

class itkMetaImageIOFactory(itk.ITKCommonBasePython.itkObjectFactoryBase):
    r"""Proxy of C++ itkMetaImageIOFactory class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMetaImageIOFactory_Pointer"""
        return _itkMetaImageIOPython.itkMetaImageIOFactory___New_orig__()

    @staticmethod
    def RegisterOneFactory():
        r"""RegisterOneFactory()"""
        return _itkMetaImageIOPython.itkMetaImageIOFactory_RegisterOneFactory()
    __swig_destroy__ = _itkMetaImageIOPython.delete_itkMetaImageIOFactory

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMetaImageIOFactory

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMetaImageIOPython.itkMetaImageIOFactory_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMetaImageIOFactory

        Create a new object of the class itkMetaImageIOFactory and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMetaImageIOFactory.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMetaImageIOFactory.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMetaImageIOFactory.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMetaImageIOFactory in _itkMetaImageIOPython:
_itkMetaImageIOPython.itkMetaImageIOFactory_swigregister(itkMetaImageIOFactory)

